@@ -2,7 +2,7 @@
 #
 # raccess4vbox3.tcl
 #
-# $Id: raccess4vbox3.tcl,v 1.5 2002/03/02 14:50:52 pape Exp $
+# $Id: raccess4vbox3.tcl,v 1.7 2003/10/17 13:14:33 pape Exp $
 #
 #    Copyright (C) 2000  G. Pape <pape@smarden.org>
 #
@@ -230,6 +230,7 @@ proc wait { what } {
 
 proc play { args } {
     global tuning
+    global vbxv_callerid vbxv_callername vbxv_localphone vbxv_savevbox
 
     raccess_log D "play: $args"
     set carg [ raccess_parseargs $args ]
@@ -257,12 +258,16 @@ proc play { args } {
 		    set that "OK"
 		} else {
 		    raccess_log D "play: command $m: $rthat"
-		    foreach line [ split "$rthat" \n ] {
-			raccess_log D "play: command $m: part: $line"
-			set that [ raccess_run "play $line" ]
-			if { [ string compare $that "EXIT" ] == 0 } {
-			    return "EXIT"
+		    if { [ string length $rthat ] > 0 } {
+			foreach line [ split "$rthat" \n ] {
+			    raccess_log D "play: command $m: part: $line"
+			    set that [ raccess_run "play $line" ]
+			    if { [ string compare $that "EXIT" ] == 0 } {
+				return "EXIT"
+			    }
 			}
+		    } else {
+		        set that "OK"
 		    }
 		}
 		continue
@@ -858,9 +863,9 @@ for { set batch 0 } { [ info exists run($batch) ] } { incr batch } {
 if { [ file isfile "$vbxv_saveulaw" ] && [ file isfile "$vbxv_savevbox" ] } {
     if { [ info exists tuning(callhandler) ] } {
         raccess_log I \
-                "Running callhandler: $tuning(callhandler) \"$vbxv_saveulaw\" \"$vbxv_callername\" \"$vbxv_callerid\" \"$vbxv_username\""
+                "Running callhandler: $tuning(callhandler) \"$vbxv_saveulaw\" \"$vbxv_callername\" \"$vbxv_callerid\" \"$vbxv_username\" \"$vbxv_localphone\""
         if [ catch { exec -- $tuning(callhandler) \
-                "$vbxv_saveulaw" "$vbxv_callername" "$vbxv_callerid" "$vbxv_username" } that ] {
+                "$vbxv_saveulaw" "$vbxv_callername" "$vbxv_callerid" "$vbxv_username" "$vbxv_localphone"} that ] {
             raccess_log E "Error on running callhandler: $that"
         }
     }
